"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Case = require("case");
const config_1 = require("./config");
const config = config_1.getConfig();
function transformToDb(value) {
    return config.caseTransform ? snakeCase(value) : value;
}
exports.transformToDb = transformToDb;
function transformToEntity(value) {
    return config.caseTransform ? camelCase(value) : value;
}
exports.transformToEntity = transformToEntity;
function camelCase(value) {
    return transform(value, Case.camel);
}
exports.camelCase = camelCase;
function snakeCase(value) {
    return transform(value, Case.snake);
}
exports.snakeCase = snakeCase;
function transform(value, func) {
    const type = typeof value;
    if (type === 'string') {
        return func(value);
    }
    else if (type === 'object') {
        if (value instanceof Array) {
            return value.map(v => transform(v, func));
        }
        else {
            const tmp = {};
            Object.keys(value).forEach(k => {
                tmp[func(k)] = value[k];
            });
            return tmp;
        }
    }
    return value;
}
//# sourceMappingURL=case_transform.js.map