"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const query_1 = require("./query");
const case_transform_1 = require("./case_transform");
class Client {
    constructor(db) {
        this.db = db;
    }
    count(table) {
        return query_1.count(table, (sql, resolve, reject) => {
            this.db.query(sql, (err, results) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(results[0].count);
                }
            });
        });
    }
    select(columns) {
        return query_1.select(columns, createExecutor(this.db));
    }
    insertInto(table) {
        return query_1.insertInto(table, createExecutor(this.db));
    }
    deleteFrom(table) {
        return query_1.deleteFrom(table, createExecutor(this.db));
    }
    update(table) {
        return query_1.update(table, createExecutor(this.db));
    }
    end() {
        return new Promise((resolve, reject) => {
            this.db.end((err) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    }
    query(sql, values) {
        return new Promise((resolve, reject) => {
            this.db.query(sql, values, (err, results) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(results);
                }
            });
        });
    }
}
exports.Client = Client;
function createExecutor(db) {
    return (sql, resolve, reject) => {
        db.query(sql, (err, results) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(case_transform_1.transformToEntity(results));
            }
        });
    };
}
//# sourceMappingURL=client.js.map